# django-grainy

[![PyPI](https://img.shields.io/pypi/v/django-grainy.svg?maxAge=60)](https://pypi.python.org/pypi/django-grainy)
[![PyPI](https://img.shields.io/pypi/pyversions/django-grainy.svg?maxAge=600)](https://pypi.python.org/pypi/django-grainy)
[![Travis CI](https://img.shields.io/travis/20c/django-grainy.svg?maxAge=60)](https://travis-ci.org/20c/django-grainy)
[![Codecov](https://img.shields.io/codecov/c/github/20c/django-grainy/master.svg?maxAge=60)](https://codecov.io/github/20c/django-grainy)

Granular permissions for django

## Supported Django Versions

- Django 2.2
- Django 3.0
- Django 3.1

## Documentation

- **stable**: http://django-grainy.readthedocs.io/en/stable/
- **latest**: http://django-grainy.readthedocs.io/en/latest/
